import { type ReactElement } from 'react';
import type { SirenStyleProps } from '../types';
/**
 * Renders a header component with a title and a "Clear All" (deletes all the notifications till date) action.
 *
 * @component
 * @example
 * <Header
 *   title="Notification Center"
 *   styles={customStyles}
 *   onClearAllNotifications={() => console.log('All notifications cleared')}
 *   clearAllDisabled={false}
 * />
 *
 * @param {Object} props - The properties passed to the Header component.
 * @param {string} props.title - The title to be displayed in the header.
 * @param {Object} props.styles - Custom styles to apply to the header component.
 * @param {Function} props.onClearAllNotifications - A callback function that is called when the "Clear All" action is triggered.
 * @param {boolean} props.clearAllDisabled - Disables the clear all button.
 */
declare const Header: (props: {
    title: string;
    styles: Partial<SirenStyleProps>;
    onPressClearAll: () => void;
    clearAllDisabled: boolean;
    hideClearAll?: boolean;
}) => ReactElement;
export default Header;
//# sourceMappingURL=header.d.ts.map