import React from 'react';
import type { SirenInboxIconProps } from '../types';
/**
 * `SirenInboxIcon` displays an icon representing the entry point to view notifications.
 *
 * @component
 * @example
 * <SirenInboxIcon
 *   theme={customTheme}
 *   notificationIcon={<CustomIcon />}
 *   darkMode={true}
 *   onError={(error) => console.error(error)}
 * />
 *
 * @param {Object} props - Props for configuring the SirenInboxIcon component.
 * @param {Object} [props.theme={}] - Theme object for custom styling of the badge.
 * @param {JSX.Element} [props.notificationIcon] - Custom icon to be used as the notification indicator.
 * @param {boolean} [props.darkMode=false] - Enables dark mode for the badge.
 * @param {boolean} [props.onPress=() => null] - Function for handling press of icon.
 * @param {boolean} [props.disabled=false] - Disable click handler of icon.
 */
declare const SirenInboxIcon: (props: SirenInboxIconProps) => React.JSX.Element;
export default SirenInboxIcon;
//# sourceMappingURL=sirenInboxIcon.d.ts.map