import React from 'react';
import { Siren } from 'test_notification';
import type { SirenProviderConfigProps } from '../types';
import { VerificationStatus } from '../utils/constants';
type SirenContextProp = {
    siren: Siren | null;
    verificationStatus: VerificationStatus;
};
interface SirenProvider {
    config: SirenProviderConfigProps;
    children: React.ReactNode;
}
export declare const SirenContext: React.Context<SirenContextProp>;
/**
 * Use `useSirenContext` hook to access Siren notifications context within your component.
 *
 * @example
 * const {
 *   siren,
 *   verificationStatus
 * } = useSirenContext();
 *
 * @returns {SirenContextProp} The Siren notifications context.
 */
export declare const useSirenContext: () => SirenContextProp;
/**
 * Provides a React context for Siren notifications, making Siren SDK functionality
 * available throughout your React application.
 *
 * `SirenProvider` initializes the Siren SDK with given configuration and manages the state for siren and verificationStatus.
 *
 * @component
 * @example
 * const config = {
 *   userToken: "user_token_here",
 *   recipientId: "recipient_id_here"
 * };
 *
 * <SirenProvider config={config}>
 *   <YourComponent />
 * </SirenProvider>
 *
 * @param {Object} props - Props for configuring the SirenProvider.
 * @param {SirenProviderConfig} props.config - Configuration for initializing the Siren SDK.
 * @param {React.ReactNode} props.children - Child components that will have access to the Siren context.
 */
declare const SirenProvider: React.FC<SirenProvider>;
export default SirenProvider;
//# sourceMappingURL=sirenProvider.d.ts.map